@@ -12,15 +12,12 @@ mod commands;
 mod queries;
 mod register_apis;
 
-use crate::client::{config_handler::Config, connections::Session, errors::Error};
+use crate::client::{connections::Session, errors::Error, Config};
 use crate::messaging::data::{CmdError, DataCmd};
 use crate::types::{Chunk, ChunkAddress, Keypair, PublicKey};
 use lru::LruCache;
 use rand::rngs::OsRng;
-use std::{
-    path::Path,
-    {collections::HashSet, net::SocketAddr, sync::Arc},
-};
+use std::sync::Arc;
 use tokio::{
     sync::{mpsc::Receiver, RwLock},
     time::Duration,
@@ -55,12 +52,7 @@ impl Client {
     ///
     /// TODO: update once data types are crdt compliant
     ///
-    pub async fn new(
-        optional_keypair: Option<Keypair>,
-        config_file_path: Option<&Path>,
-        bootstrap_config: Option<HashSet<SocketAddr>>,
-        query_timeout: u64,
-    ) -> Result<Self, Error> {
+    pub async fn new(optional_keypair: Option<Keypair>, config: Config) -> Result<Self, Error> {
         let mut rng = OsRng;
 
         let keypair = match optional_keypair {
@@ -78,15 +70,11 @@ impl Client {
             }
         };
 
-        let mut qp2p_config = Config::new(config_file_path, bootstrap_config).await.qp2p;
-        // We use feature `no-igd` so this will use the echo service only
-        qp2p_config.forward_port = true;
-
         // Incoming error notifiers
         let (err_sender, err_receiver) = tokio::sync::mpsc::channel::<CmdError>(10);
 
         // Create the session with the network
-        let mut session = Session::new(qp2p_config, err_sender)?;
+        let mut session = Session::new(config.qp2p, err_sender)?;
 
         let client_pk = keypair.public_key();
 
@@ -99,7 +87,7 @@ impl Client {
             keypair,
             session,
             incoming_errors: Arc::new(RwLock::new(err_receiver)),
-            query_timeout: Duration::from_secs(query_timeout),
+            query_timeout: config.query_timeout,
             blob_cache: Arc::new(RwLock::new(LruCache::new(BLOB_CACHE_CAP))),
         };
 
@@ -168,7 +156,10 @@ mod tests {
     use super::*;
     use crate::client::utils::test_utils::{create_test_client, create_test_client_with};
     use anyhow::Result;
-    use std::net::{IpAddr, Ipv4Addr, SocketAddr};
+    use std::{
+        collections::HashSet,
+        net::{IpAddr, Ipv4Addr, SocketAddr},
+    };
 
     #[tokio::test(flavor = "multi_thread")]
     async fn client_creation() -> Result<()> {
