@@ -15,7 +15,7 @@ use xor_name::XorName;
 
 /// Authority of a network peer.
 #[derive(Clone, Debug, Eq, PartialEq, serde::Deserialize, serde::Serialize)]
-pub struct DataSigned {
+pub struct ServiceAuth {
     /// Peer's public key.
     pub public_key: PublicKey,
     /// Peer's signature.
@@ -24,7 +24,7 @@ pub struct DataSigned {
 
 /// Authority of a single peer.
 #[derive(Clone, Eq, PartialEq, custom_debug::Debug, serde::Deserialize, serde::Serialize)]
-pub struct NodeSigned {
+pub struct NodeAuth {
     /// Section key of the source.
     pub section_pk: BlsPublicKey,
     /// Public key of the source peer.
@@ -36,14 +36,14 @@ pub struct NodeSigned {
     pub signature: EdSignature,
 }
 
-impl NodeSigned {
+impl NodeAuth {
     /// Construct verified node authority by signing a payload.
     pub(crate) fn authorize(
         section_pk: BlsPublicKey,
         keypair: &EdKeypair,
         payload: impl AsRef<[u8]>,
-    ) -> Authority<Self> {
-        Authority(NodeSigned {
+    ) -> AuthorityProof<Self> {
+        AuthorityProof(NodeAuth {
             section_pk,
             public_key: keypair.public,
             signature: keypair.sign(payload.as_ref()),
@@ -53,7 +53,7 @@ impl NodeSigned {
 
 /// Authority of a single peer that uses it's BLS Keyshare to sign the message.
 #[derive(Clone, Debug, Eq, PartialEq, serde::Deserialize, serde::Serialize)]
-pub struct BlsShareSigned {
+pub struct BlsShareAuth {
     /// Section key of the source.
     pub section_pk: BlsPublicKey,
     /// Name in the source section.
@@ -62,15 +62,15 @@ pub struct BlsShareSigned {
     pub sig_share: SigShare,
 }
 
-impl BlsShareSigned {
+impl BlsShareAuth {
     /// Construct verified authority of a single node's share of section authority.
     pub(crate) fn authorize(
         section_pk: BlsPublicKey,
         src_name: XorName,
         key_share: &SectionKeyShare,
         payload: impl AsRef<[u8]>,
-    ) -> Authority<Self> {
-        Authority(BlsShareSigned {
+    ) -> AuthorityProof<Self> {
+        AuthorityProof(BlsShareAuth {
             section_pk,
             src_name,
             sig_share: SigShare {
@@ -84,7 +84,7 @@ impl BlsShareSigned {
 
 /// Authority of a whole section.
 #[derive(Clone, Debug, Eq, PartialEq, serde::Deserialize, serde::Serialize)]
-pub struct SectionSigned {
+pub struct SectionAuth {
     /// Section key of the source.
     pub section_pk: BlsPublicKey,
     /// Name in the source section.
@@ -93,13 +93,13 @@ pub struct SectionSigned {
     pub sig: KeyedSig,
 }
 
-impl SectionSigned {
+impl SectionAuth {
     /// Try to construct verified section authority by aggregating a new share.
     pub(crate) fn try_authorize(
         aggregator: &mut SignatureAggregator,
-        share: BlsShareSigned,
+        share: BlsShareAuth,
         payload: impl AsRef<[u8]>,
-    ) -> Result<Authority<Self>, AggregatorError> {
+    ) -> Result<AuthorityProof<Self>, AggregatorError> {
         let sig = aggregator.add(payload.as_ref(), share.sig_share.clone())?;
 
         if share.sig_share.public_key_set.public_key() != sig.public_key {
@@ -110,7 +110,7 @@ impl SectionSigned {
             return Err(AggregatorError::InvalidShare);
         }
 
-        Ok(Authority(SectionSigned {
+        Ok(AuthorityProof(SectionAuth {
             section_pk: share.section_pk,
             src_name: share.src_name,
             sig,
@@ -125,13 +125,13 @@ impl SectionSigned {
 ///
 /// Validation is defined by the [`VerifyAuthority`] impl for `T`.
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub struct Authority<T>(T);
+pub struct AuthorityProof<T>(T);
 
-impl<T: VerifyAuthority> Authority<T> {
+impl<T: VerifyAuthority> AuthorityProof<T> {
     /// Verify the authority of `inner`.
     ///
     /// This is the only way to construct an instance of [`Authority`] from a `T`. Since it's
-    /// implemented to call [`VerifyAuthority::verify_authority`] an instance of `Authority<T>` is
+    /// implemented to call [`VerifyAuthority::verify_authority`] an instance of `AuthorityProof<T>` is
     /// guaranteed to be valid with respect to that trait's impl.
     pub fn verify(inner: T, payload: impl AsRef<[u8]>) -> Result<Self> {
         inner.verify_authority(payload).map(Self)
@@ -143,7 +143,7 @@ impl<T: VerifyAuthority> Authority<T> {
     }
 }
 
-impl<T> core::ops::Deref for Authority<T> {
+impl<T> core::ops::Deref for AuthorityProof<T> {
     type Target = T;
 
     fn deref(&self) -> &Self::Target {
@@ -161,7 +161,7 @@ pub trait VerifyAuthority: Sized + sealed::Sealed {
     fn verify_authority(self, payload: impl AsRef<[u8]>) -> Result<Self>;
 }
 
-impl VerifyAuthority for DataSigned {
+impl VerifyAuthority for ServiceAuth {
     fn verify_authority(self, payload: impl AsRef<[u8]>) -> Result<Self> {
         self.public_key
             .verify(&self.signature, payload)
@@ -169,9 +169,9 @@ impl VerifyAuthority for DataSigned {
         Ok(self)
     }
 }
-impl sealed::Sealed for DataSigned {}
+impl sealed::Sealed for ServiceAuth {}
 
-impl VerifyAuthority for NodeSigned {
+impl VerifyAuthority for NodeAuth {
     fn verify_authority(self, payload: impl AsRef<[u8]>) -> Result<Self> {
         self.public_key
             .verify(payload.as_ref(), &self.signature)
@@ -179,9 +179,9 @@ impl VerifyAuthority for NodeSigned {
         Ok(self)
     }
 }
-impl sealed::Sealed for NodeSigned {}
+impl sealed::Sealed for NodeAuth {}
 
-impl VerifyAuthority for BlsShareSigned {
+impl VerifyAuthority for BlsShareAuth {
     fn verify_authority(self, payload: impl AsRef<[u8]>) -> Result<Self> {
         // Signed chain is required for accumulation at destination.
         if self.sig_share.public_key_set.public_key() != self.section_pk {
@@ -195,9 +195,9 @@ impl VerifyAuthority for BlsShareSigned {
         Ok(self)
     }
 }
-impl sealed::Sealed for BlsShareSigned {}
+impl sealed::Sealed for BlsShareAuth {}
 
-impl VerifyAuthority for SectionSigned {
+impl VerifyAuthority for SectionAuth {
     fn verify_authority(self, payload: impl AsRef<[u8]>) -> Result<Self> {
         if !self.section_pk.verify(&self.sig.signature, payload) {
             return Err(Error::InvalidSignature);
@@ -206,7 +206,7 @@ impl VerifyAuthority for SectionSigned {
         Ok(self)
     }
 }
-impl sealed::Sealed for SectionSigned {}
+impl sealed::Sealed for SectionAuth {}
 
 mod sealed {
     #[allow(missing_docs, unreachable_pub)]
